onRatingSelected abstract method
Called when a user selects a rating in the feedback UI.
rating - The selected rating (1-5)
Implementation
void onRatingSelected(int rating);
Called when a user selects a rating in the feedback UI.
rating - The selected rating (1-5)
void onRatingSelected(int rating);