reset method
Resets all SDK data.
Clears all locally stored experience logs and feedback history. Useful when a user logs out of your app.
Example:
await Appero.instance.reset();
Implementation
Future<void> reset() async {
_feedbackPromptSubscription?.cancel();
await _methodChannel.invokeMethod('reset');
}