ExperienceRating enum
Experience rating levels for logging user interactions.
These ratings are used to categorize user experiences and trigger feedback prompts based on the configured feedback flow.
Values
- strongPositive → const ExperienceRating
-
Very satisfied (value: 5)
const ExperienceRating(5) - positive → const ExperienceRating
-
Satisfied (value: 4)
const ExperienceRating(4) - neutral → const ExperienceRating
-
Neutral (value: 3)
const ExperienceRating(3) - negative → const ExperienceRating
-
Dissatisfied (value: 2)
const ExperienceRating(2) - strongNegative → const ExperienceRating
-
Very dissatisfied (value: 1)
const ExperienceRating(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The numeric value associated with this rating (1-5)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNativeString(
) → String - Converts this rating to the native SDK string format.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ExperienceRating> - A constant List of the values in this enum, in order of their declaration.