ApperoRatingImages class

Rating images configuration for Appero SDK themes.

Provides custom rating icon images as Flutter asset paths. The images must be in order from lowest to highest rating: 1 star / very negative, 2 stars / negative, 3 stars / neutral, 4 stars / positive, 5 stars / very positive

Example:

const ratingImages = ApperoRatingImages(
  strongNegative: 'images/alt_ic_1.png',
  negative: 'images/alt_ic_2.png',
  neutral: 'images/alt_ic_3.png',
  positive: 'images/alt_ic_4.png',
  strongPositive: 'images/alt_ic_5.png',
);

Constructors

ApperoRatingImages({required String strongNegative, required String negative, required String neutral, required String positive, required String strongPositive})
const
ApperoRatingImages.fromList(List<String> assetPaths)
Creates rating images from a list of 5 asset paths.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
negative String
Asset path for rating 2 (Negative / Dissatisfied)
final
neutral String
Asset path for rating 3 (Neutral)
final
positive String
Asset path for rating 4 (Positive / Satisfied)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strongNegative String
Asset path for rating 1 (Strong Negative / Very Dissatisfied)
final
strongPositive String
Asset path for rating 5 (Strong Positive / Very Satisfied)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List<String>
Converts this rating images configuration to a list for serialization
toMap() Map<String, dynamic>
Converts this rating images configuration to a map for platform channel communication
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited